@@ -107,7 +107,7 @@ pub struct Actor<'a> {
   layout: Option<Box<dyn Layout + 'a>>,
   focused_sub_actor: usize,
   focused: bool,
-  needsUpdate: bool,
+  needs_update: bool,
   pub node: Option<Node>,
   style: Option<Style>
 }
@@ -172,7 +172,7 @@ impl<'a> Actor<'a> {
       layout: None,
       focused_sub_actor: 0,
       focused: false,
-      needsUpdate: false,
+      needs_update: false,
       node: None,
       style: None
     }
@@ -181,8 +181,7 @@ impl<'a> Actor<'a> {
   pub fn init_gl(&mut self, viewport_width: u32, viewport_height: u32) {
     self.viewport_width = viewport_width;
     self.viewport_height = viewport_height;
-
-    println!("init_gl {}", self.name);
+    //println!("init_gl {}", self.name);
 
     unsafe {
       let (mut vertex_array_buffer, mut elem_array_buffer) = (0, 0);
@@ -251,7 +250,7 @@ impl<'a> Actor<'a> {
                       &data[0] as *const u8 as *const c_void);
             gl::GenerateMipmap(gl::TEXTURE_2D);
           }
-          Err(err) => println!("Fail to load a image")
+          Err(err) => println!("Fail to load a image {:?}", err)
         }
 
       }
@@ -303,9 +302,9 @@ impl<'a> Actor<'a> {
      }
   }
   pub fn animate(&mut self) {
-    if self.needsUpdate {
+    if self.needs_update {
         self.layout_sub_actors();
-      self.needsUpdate = false;
+      self.needs_update = false;
     }
 
     if self.translation_x_animation_running == true {
@@ -467,13 +466,13 @@ impl<'a> Actor<'a> {
 
   // Marks the layer’s contents as needing to be updated.
   pub fn set_needs_layout(&mut self, stretch: &mut Option<Stretch>) {
-     self.needsUpdate = true;
+     self.needs_update = true;
 
     if let Some(stretch_obj) = stretch {
       if let Some(style_obj) = self.style {
         self.node = Some(stretch_obj.new_node(style_obj, vec![]).unwrap());
       } else {
-        println!("default style: {}: {},{}", self.name, self.width, self.height);
+        //println!("default style: {}: {},{}", self.name, self.width, self.height);
         self.node = Some(stretch_obj.new_node(Style {
           size: Size { 
               width: Dimension::Points(self.width as f32), 
@@ -491,6 +490,7 @@ impl<'a> Actor<'a> {
       }
     }
     for sub_actor in self.sub_actor_list.iter_mut() {
+       sub_actor.init_gl(self.viewport_width, self.viewport_height);
        sub_actor.set_needs_layout(stretch);
       if !self.node.is_none() {
         match stretch.as_mut().unwrap().add_child(self.node.unwrap(),
@@ -591,13 +591,8 @@ impl<'a> Actor<'a> {
     }
   }
 
-  pub fn add_sub_actor(&mut self, mut actor: Actor<'a>) {
-    println!("{} : {}, {}", self.name, self.viewport_width, self.viewport_height);
-
-    // FIXME
-    // actor.init_gl(self.viewport_width, self.viewport_height);
-    actor.init_gl(1920, 1080);
-    //println!("stage::add_actor");
+  pub fn add_sub_actor(&mut self, actor: Actor<'a>) {
+    //println!("{} : {}, {}", self.name, self.viewport_width, self.viewport_height);
     self.sub_actor_list.push(actor);
   }
 }
